function out=hermite(in)
% in:   vector, which contains natural numbers between 0 an 170;
%       the input format must be uint8;
%       the number represents the order of the hermite polynomial;
% out:  matrix, wich contains the polynomial coefficients for the 
%       hermite polynomial of the n-th order;
%       the rows referre to the order of the polynomial belonging to in;
%       the columns represent the coefficient of the polynomial;

if nargin<1||isempty(in)
    in=0;
elseif not(isa(in,'uint8'))||any(in(:)>170)
    error('Argument must be natural number < 171 (uint8)!')
elseif not(isvector(in))
    error('Argument must be scalar or vector!')
end

in=double(in(:)');
in_max=max(in);
in_num=numel(in);
k_max=floor(in_max/2);
k=repmat((0:1:k_max)',[1,in_num]);
n=repmat(in,[k_max+1,1]);
k_ind=repmat(in,[k_max+1,1]);
k_ind=in_max+1-(k_ind-repmat((0:2:in_max)',[1,in_num]));
k_ind=k_ind(:);
k_ind1=reshape(repmat(1:1:in_num,[k_max+1,1]),size(k_ind));
k_ind_ind=k_ind<=in_max+1;
k_ind=k_ind(k_ind_ind);
k_ind1=k_ind1(k_ind_ind);
out1=(-1).^k.*gamma(n+1)./(gamma(k+1).*gamma(n-2*k+1)).*2.^(n-2*k);
out1_ind=out1~=0;
out_size=[in_max+1,in_num];
out=zeros(out_size);
out(sub2ind(out_size,k_ind,k_ind1))=out1(out1_ind);
out=out';


