function [x_out,y_out]=hermiteval(x,n)
% poly:     matrix, which contains the polynomial coefficients of the
%           polynomial that should be evaluated;
%           the rows represent to the different polynomials;
%           the columns represent the coefficients of the polynomial;
% x:        vector containing the points, where the polynomial should be
%           evaluated;
% n:        the order of the hermitepolynomial regarding to the rows of
%           poly;
% x_out:    matrix, which contains the points, where the hermite function
%           was evaluated (same values as x, but
%           size(x_out)=[numel(n),numel(x)]);
% y_out:    matrix, containing the values of the hermite function at the
%           points x_out;

if nargin<1||isempty(x)
  x=0;
elseif not(isvector(x))
    error('Second argument must be a scalar or vector!')
end
if nargin<2||isempty(n)
  n=unit8(0);
elseif not(isvector(n))
    error('Argument must be scalar or vector!')
elseif not(isa(n,'uint8'))||any(n(:)>170)
    error('Argument must be natural number < 171 (uint8)!')
end

poly=hermite(n);
x_num=numel(x);
poly_size=size(poly);
poly1=repmat(poly,[1,1,x_num]);
x1=repmat(reshape(x,[1,1,x_num]),size(poly));
n1=repmat(double(n(:)),[1,1,x_num]);
np=repmat((poly_size(2)-1):-1:0,[poly_size(1),1,x_num]);
y1=sum(poly1.*x1.^np,2).*exp(-x1(:,1,:).^2/2).*2.^(-n1/2)./sqrt(gamma(n1+1)*sqrt(pi));

x_out=zeros(poly_size(1),x_num);
x_out(:)=x1(:,1,:);
y_out=zeros(poly_size(1),x_num);
y_out(:)=y1(:);
