function [x_out,rho_out]=t_develope(n,coef,fine_x,fine_t,w,x_lim,is_norm)
%
%n :       vector containing the order of the hermite function
%coef:     vector containing the weighting for the hermite polynomial,
%          same length as n
%fine_x:   number which represents the number of values for x
%fine_t:   number which represents the number of values for t
%w:        angular frequency for the time developement
%x_lim:    positive limit for x
%is_norm:  boolean containing the information wheather the coefficients
%          are already normalized (true) or not (false)
%x_out:    matrix of size [fine_x,fine_t] containing x values for all times
%rho_out:  matrix of size [fine_x,fine_t] containing the
%          propabilitydensity for finding the particle at position x
if nargin<7||isempty(n)||isempty(coef)||isempty(fine_x)||isempty(fine_t)...
    ||isempty(w)||isempty(x_lim)||isempty(is_norm)
    error('Input must be complete!')
end
if not(islogical(is_norm))
    error('Input argument is_norm must be binary!')
end
if not(all(size(n)==size(coef)))
    error('Input n and Input coef must have same size!')
end
n_num=numel(n);
x=linspace(-x_lim,x_lim,fine_x);
[x_phi,phi]=hermiteval(x,n);
t=repmat(reshape(linspace(0,2*pi/w,fine_t),[1,1,fine_t]),[n_num,fine_x]);
n1=repmat(double(n(:)),[1,fine_x,fine_t]);
if is_norm==true
    coef1=repmat(coef(:),[1,fine_x,fine_t]);
else
    coef1=repmat(coef(:)/sqrt(sum(coef(:).^2)),[1,fine_x,fine_t]);
end
x_phi=repmat(x_phi,[1,1,fine_t]);
phi=repmat(phi,[1,1,fine_t]);
phi=sum(phi.*exp(-i*w*t.*(n1+0.5)).*coef1,1);
rho=conj(phi).*phi;

x_out=reshape(x_phi(1,:,:),[fine_x,fine_t]);
rho_out=reshape(rho(1,:,:),[fine_x,fine_t]);
